<?php
/**
 * MoViTheme functions and definitions
 *
 * @link http://codex.wordpress.org/Theme_Development
 * @link http://codex.wordpress.org/Child_Themes
 *
 * Functions that are not pluggable (not wrapped in function_exists()) are
 * instead attached to a filter or action hook.
 *
 * For more information on hooks, actions, and filters,
 * @link http://codex.wordpress.org/Plugin_API
 *
 * @package WordPress
 * @subpackage MoViTheme
 * @since MoViTheme 1.0
 */
/* Make theme ready for localization */
load_theme_textdomain("MoViTheme", get_stylesheet_directory());
/**
 * Set up the content width value based on the theme's design.
 * MoViTheme override to 300px for responsive design
 *
 * @see twentytwelve_content_width()
 *
 * @since MoViTheme 1.0
 */
if(!isset($content_width)) {
	$content_width = 300;
}
/**
 * MoViTheme setup.
 *
 * Sets up theme defaults and registers the various WordPress features that
 * MoViTheme supports.
 *
 * @uses load_theme_textdomain() For translation/localization support.
 * @uses add_editor_style() To add a Visual Editor stylesheet.
 * @uses add_theme_support() To add support for post thumbnails, automatic feed links,
 * 	custom background, and post formats.
 * @uses register_nav_menu() To add support for navigation menus.
 * @uses set_post_thumbnail_size() To set a custom post thumbnail size.
 *
 * @since MoViTheme 1.0
 */
function movitheme_setup() {
	register_nav_menu("secondary", __("Secondary Menu", "movitheme"));
}
add_action("after_setup_theme", "movitheme_setup");
/**
 * Register MoViTheme widget area.
 *
 * @since MoViTheme 1.0
 */
function movitheme_widgets_init() {
	register_sidebar(array(
		"name"          => __("Widget Main", "movitheme"),
		"id"            => "widgetmain-1",
		"description"   => __("Main sidebar that appears centered on page", "movitheme"),
		"before_widget" => '<aside id="%1$s" class="widget %2$s">',
		"after_widget"  => "</aside>",
		"before_title"  => "<h1 class=\"widget-title\">",
		"after_title"   => "</h1>",
	));
	
	register_sidebar(array(
		"name"          => __("Widget Footer", "movitheme"),
		"id"            => "widgetfooter-1",
		"description"   => __("Footer sidebar", "movitheme"),
		"before_widget" => '<aside id="%1$s" class="widget %2$s">',
		"after_widget"  => "</aside>",
		"before_title"  => "<h1 class=\"widget-title\">",
		"after_title"   => "</h1>",
	));

	unregister_sidebar("sidebar-1");
	unregister_sidebar("sidebar-2");
	unregister_sidebar("sidebar-3");
}
/* Priority has been set to 11 which is a lower priority than default.
 * Hook will be executed after the default
 */
add_action("widgets_init", "movitheme_widgets_init", 11);
/* Register customizer for MoViTheme
 * 
 */
function movitheme_customize_register($wp_customize) {
	$wp_customize->remove_section("title_tagline");
	$wp_customize->remove_section("background_image");
}
add_action("customize_register", "movitheme_customize_register");
/* Include MoViTheme specific widgets
 * 
 */
require_once("last-article-widget.php");
require_once("last-articles-widget.php");
require_once("social-links-widget.php");
