<?php
class LastArticlesWidget extends WP_Widget {
	public function __construct() {
		parent::__construct(
			"LastArticlesWidgetID",
			__("Last Articles", "MoViTheme"),
			array("description" => __("Shows last articles in preview boxes"))
			);
	}

	public function form($instance) {
		$title = isset($instance["title"]) == true ? $instance["title"] :
			__("Last articles", "MoViTheme");
		$numberOfArticles = isset($instance["number-of-articles"]) == true ?
			$instance["number-of-articles"] : 4;
		?>
		<p>
			<label for="<?php echo $this->get_field_id("title"); ?>">
				<?php _e("Title:", "MoViTheme"); ?>
			</label>
			<input
				id="<?php echo $this->get_field_id("title"); ?>"
				name="<?php echo $this->get_field_name("title"); ?>"
				type="text" value="<?php echo esc_attr($title); ?>" />
		</p>
		<p>
			<label for="<?php echo $this->get_field_id("number-of-articles"); ?>">
				<?php _e("Number of articles to show:", "MoViTheme"); ?>
			</label>
			<select id="<?php echo $this->get_field_id("number-of-articles"); ?>"
				name="<?php echo $this->get_field_name("number-of-articles"); ?>">
				<option value="4" <?php echo($numberOfArticles == 4) ? "selected" : "" ?>>4</option> 
				<option value="9" <?php echo($numberOfArticles == 9) ? "selected" : "" ?>>9</option>
				<option value="14" <?php echo($numberOfArticles == 14) ? "selected" : "" ?>>14</option>
			</select>
		</p>
		<p>
			<label for="<?php echo $this->get_field_id("archive-category"); ?>">
				<?php _e("Select archive category:", "MoViTheme"); ?>
			</label>
			<select id="<?php echo $this->get_field_id("archive-category"); ?>"
				name="<?php echo $this->get_field_name("archive-category"); ?>">
				<?php
					$category_ids = get_all_category_ids();
					
					foreach($category_ids as $cat_id) {
						$cat_name = get_cat_name($cat_id);
						?>
						<option value="<?php echo $cat_id; ?>"<?php echo($instance["archive-category"] == $cat_id) ? "selected" : "" ?>><?php echo $cat_name; ?></option>
					<?php }
				?>
			</select>
		</p>
		<?php
	}

	public function update($new_instance, $old_instance) {
		$instance = array();
		$instance["title"] = strip_tags($new_instance["title"]);

		if(is_numeric($new_instance["number-of-articles"]) == true &&
			$new_instance["number-of-articles"] > 0)
			$instance["number-of-articles"] = $new_instance["number-of-articles"];
		else
			$instance["number-of-articles"] = $old_instance["number-of-articles"];
		
		$instance["archive-category"] = strip_tags($new_instance["archive-category"]);
		
		return $instance;
	}

	public function widget($args, $instance) {
		extract($args);
		$title = apply_filters("widget_title", $instance["title"]);
		echo $before_widget;

		$args = array(
			"post_type" => "post",
			"posts_per_page" => $instance["number-of-articles"],
			"order_by" => "date"
			);
		$featuredWidget = new WP_Query($args);
		
		if($featuredWidget->have_posts() == true) :
		?>
			<div class="widget last-articles-widget">
			<div class="heading">
				<h2><?php echo $title ?></h2>
				<p><a href="<?php echo get_category_link($instance["archive-category"]); ?>"><small><?php _e("Show all", "MoViTheme"); ?></small></a></p>
			</div>
		<?php
			while($featuredWidget->have_posts() == true) :
				$featuredWidget->the_post(); ?>
				<div class="article-thumb">
					<a href="<?php echo the_permalink(); ?>"><h3><?php echo the_title(); ?></h3></a>
					<p><small><?php echo the_date(); ?></small></p>
					<?php echo the_excerpt(); ?>
				</div>
			<?php
			endwhile;
		?>
			</div>
		<?php
		endif;
			
		wp_reset_postdata();
		echo $after_widget;
	}
}

register_widget("LastArticlesWidget");
?>
