<?php
class SocialLinksWidget extends WP_Widget {
	public function __construct() {
		parent::__construct(
			"SocialLinksWidgetID",
			__("Social Links Widget"),
			array("description" => __("Shows social links with hover effect icons"))
			);
		wp_register_script("SocialLinksWidgetScript", get_stylesheet_directory_uri() . "/js/SocialLinksWidgetScript.js");
	}

	public function form($instance) { ?>
		<p>
			<label for="<?php echo $this->get_field_id("facebook-link"); ?>"><?php _e("Facebook page url:", "MoViTheme"); ?></label>
			<input type="text" id="<?php echo $this->get_field_id("facebook-link"); ?>" name="<?php echo $this->get_field_name("facebook-link"); ?>" value="<?php echo $instance["facebook-link"]; ?>" />
		</p>
		<p>
			<label for="<?php echo $this->get_field_id("twitter-link"); ?>"><?php _e("Twitter page url:", "MoViTheme"); ?></label>
			<input type="text" id="<?php echo $this->get_field_id("twitter-link"); ?>" name="<?php echo $this->get_field_name("twitter-link"); ?>" value="<?php echo $instance["twitter-link"]; ?>" />
		</p>
		<p>
			<label for="<?php echo $this->get_field_id("linkedin-link"); ?>"><?php _e("Linkedin page url:", "MoViTheme"); ?></label>
			<input type="text" id="<?php echo $this->get_field_id("linkedin-link"); ?>" name="<?php echo $this->get_field_name("linkedin-link"); ?>" value="<?php echo $instance["linkedin-link"]; ?>" />
		</p>
		<p>
			<label for="show-feed"><?php _e("Show feed link?", "MoViTheme"); ?></label>
			<input type="checkbox" id="<?php echo $this->get_field_id("show-feed"); ?>" name="<?php echo $this->get_field_name("show-feed"); ?>" <?php
				echo ($instance["show-feed"] == true) ? "checked" : "" ?> />
		</p>
		<p>
			<label for="show-email"><?php _e("Show email?", "MoViTheme"); ?></label>
			<input type="checkbox" id="<?php echo $this->get_field_id("show-email"); ?>" name="<?php echo $this->get_field_name("show-email"); ?>" <?php
				echo ($instance["show-email"] == true) ? "checked" : "" ?> />
		</p>
		<?php
	}

	public function update($new_instance, $old_instance) {
		$instance = $new_instance;
		
		return $instance;
	}

	public function widget($args, $instance) {
		wp_enqueue_script("jquery");
		wp_enqueue_script("SocialLinksWidgetScript");
		echo $before_widget;
		
		?>
		<style type="text/css">
			img.social-link {
				padding: 0;
				margin-right: 0.5rem;
			}
		</style>
		<?php
		
		if($instance["facebook-link"] != "") : ?>
			<a href="<?php echo $instance["facebook-link"]; ?>" target="_blank"><img class="social-link" src="<?php
				echo get_stylesheet_directory_uri(); ?>/images/facebook32x32.png" alt="Facebook logo" height="32" width="32" /></a>
		<?php
		endif;
		
		if($instance["twitter-link"] != "") : ?>
			<a href="<?php echo $instance["twitter-link"]; ?>" target="_blank"><img class="social-link" src="<?php
				echo get_stylesheet_directory_uri(); ?>/images/twitter32x32.png" alt="Twitter logo" height="32" width="32" /></a>
		<?php
		endif;
		
		if($instance["linkedin-link"] != "") : ?>
			<a href="<?php echo $instance["linkedin-link"]; ?>" target="_blank"><img class="social-link" src="<?php
				echo get_stylesheet_directory_uri(); ?>/images/linkedin32x32.png" alt="Twitter logo" height="32" width="32" /></a>
		<?php
		endif;

		if($instance["show-feed"] == true) : ?>
			<a href="<?php echo get_bloginfo("url"); ?>?feed=rss" target="_blank"><img class="social-link" src="<?php
				echo get_stylesheet_directory_uri(); ?>/images/rss32x32.png" alt="Feed logo" height="32" width="32" /></a>
		<?php 
		endif;
		
		if($instance["show-email"] == true) : ?>
			<p>e-mail: <a href="mailto:<?php echo get_settings("admin_email"); ?>"><?php echo get_settings("admin_email"); ?></a></p>
		<?php 
		endif;
		
		echo $after_widget;
	}
}

register_widget("SocialLinksWidget");
?>
